@@ -1,3 +1,6 @@
+from typing import Optional
+
+
 class Asset:
     def __init__(self, latitude: float, longitude: float, **kwargs):
         self.latitude = latitude
@@ -17,8 +20,9 @@ class RealEstateAsset(Asset):
 
 
 class IndustrialActivity(Asset):
-    def __init__(self, latitude: float, longitude: float, *, type: str):
+    def __init__(self, latitude: float, longitude: float, *, location: Optional[str] = None, type: str):
         super().__init__(latitude, longitude)
+        self.location = location
         self.type = type
 
 
